summaryrefslogtreecommitdiff
path: root/hints/darwin.sh
diff options
context:
space:
mode:
Diffstat (limited to 'hints/darwin.sh')
-rw-r--r--hints/darwin.sh4
1 files changed, 2 insertions, 2 deletions
diff --git a/hints/darwin.sh b/hints/darwin.sh
index 025c0221f1..59f0d63050 100644
--- a/hints/darwin.sh
+++ b/hints/darwin.sh
@@ -85,10 +85,10 @@ esac
# -pipe: makes compilation go faster.
# -fno-common because common symbols are not allowed in MH_DYLIB
# -DDARWIN: apparently the __APPLE__ is not sanctioned by Apple
# as the way to differentiate Mac OS X. (The official line is that
# *no* cpp symbol does differentiate Mac OS X.)
-ccflags="${ccflags} -pipe -fno-common -DDARWIN"
+ccflags="${ccflags} -pipe -fno-common -DPERL_DARWIN"
# At least on Darwin 1.3.x:
#
@@ -85,10 +85,10 @@ esac
# -pipe: makes compilation go faster.
# -fno-common because common symbols are not allowed in MH_DYLIB
-# -DDARWIN: apparently the __APPLE__ is not sanctioned by Apple
+# -DPERL_DARWIN: apparently the __APPLE__ is not sanctioned by Apple
# as the way to differentiate Mac OS X. (The official line is that
# *no* cpp symbol does differentiate Mac OS X.)